.. _aorc:

AORC
####

NOAA's Analysis of Record for Calibration (AORC) Dataset
is available
`on AWS here <https://aws.amazon.com/marketplace/pp/prodview-m2sp7gsk5ts6s>`_.
for more information, check out

* `AORC version 1.1 documentation <https://www.weather.gov/media/owp/operations/aorc_v1_1_methods.pdf>`_
* `[Fall et al., (2023)] <https://onlinelibrary.wiley.com/doi/10.1111/1752-1688.13143>`_

Available Variables
-------------------


.. list-table:: Variables from AORC available in ufs2arco
   :widths: 18 50
   :header-rows: 1

   * - Variable
     - Long Name
   * - ``APCP_surface``
     - Total Precipitation
   * - ``DLWRF_surface``
     - Downward Long-Wave Rad. Flux
   * - ``DSWRF_surface``
     - Downward Short-Wave Rad. Flux
   * - ``PRES_surface``
     - Pressure
   * - ``SPFH_2maboveground``
     - Specific Humidity at 2m height
   * - ``TMP_2maboveground``
     - Temperature at 2m height
   * - ``UGRD_10maboveground``
     - U-Component of Wind at 10m height
   * - ``VGRD_10maboveground``
     - V-Component of Wind at 10m height
